# Bug fix

## Description
<!-- Please briefly describe the bug. -->

## Fix
<!-- Please provide a succinct overview of the fix. -->

# Checklist
- [ ] Regression test added; or
- [ ] Description of manual testing performed and explanation is included in the code and/or PR.
- [ ] Added to the correct milestone.

# Testing
- [ ] Tests are run against all relevant library versions (or confirm that the relevant versions are already being tested in `tox.ini`)
